<?php
/* $Id: smartytemplate.php,v 1.4 2005/07/27 06:15:07 tclineks Exp $ */

/**
 * @file
 *   Class Definition for SmartyTemplate - interface between smarty engine and smarty-based themes
 *
 * Originally derived from the phptemplate version by Brian E. Lozier (brian@massassi.net)
 *
 * @author
 *   tclineks - Travis Cline (travis dot cline at gmail dot com)
 * @author
 *   lobo - Donald A. Lobo (lobo at yahoo dot com)
 * @license
 *   http://www.gnu.org/copyleft/gpl.html Licensed under GPL
 */

// Smarty Drupal engine, by default, expects a smarty installation in ./libs
if (!class_exists('Smarty')) {  // prevent redeclaration
  require_once realpath('themes/engines/smarty/libs/Smarty.class.php');
}

class SmartyTemplate extends Smarty {
  var $path; // Path to the templates
  var $vars; // Shorcut to _tpl_vars at runtime

  /**
   * Constructor
   *
   * @param string $path the path to the templates
   *
   * @return void
   */
  function SmartyTemplate($path = null) {
    $this->path = $path;

    $this->Smarty();

    $this->vars = & $this->_tpl_vars;
    $this->template_dir = $path;
    $this->compile_dir  = $path.'/templates_c';
    $this->config_dir   = $path.'/configs';
    $this->plugins_dir  = array(realpath('themes/engines/smarty/plugins'), $path.'/plugins', 'plugins');
  }

  /**
   * Set the path to the template files.
   *
   * @param string $path path to template files
   *
   * @return void
   */
  function set_path($path) {
    $this->path = $path;
  }

  /**
   * Set a template variable.
   *
   * @param string $name name of the variable to set
   * @param mixed $value the value of the variable
   *
   * @return void
   */
  function set($name, $value) {
    $this->assign($name, $value);
  }

  /**
   * Set a bunch of variables at once using an associative array.
   *
   * @param array $vars array of vars to set
   * @param bool $clear whether to completely overwrite the existing vars
   *
   * @return void
   */
  function set_vars($vars, $clear = false) {
    if ($clear) {
      $this->clear_all_assign();
    }
    foreach ($vars as $name => $value) {
      $this->assign($name, $value);
    }
  }

  /**
   * Open, parse, and return the template file.
   *
   * @param string string the template file name
   *
   * @return string
   */
  function fetch($file, $cache_id = null, $compile_id = null) {
    $this->_register_functions();
    return parent::fetch($file, $cache_id, $compile_id);              // Return the contents
  }

  /**
   * Performs runtime registration of functions to enable ease of use in templates.
   *
   * register_functions would be defined in the theme-specific smartytemplate.php
   */
  function _register_functions() {
    if (function_exists('register_functions'))
    {
      $functions = array_merge($functions, register_functions());
      foreach ($functions as $key => $value)
        $this->register_function($key, $value);
    }
  }
}
?>
